@@ -21,7 +21,6 @@
 #' also a Cox regression model for event-free survival.
 #' @param fitter Routine to fit the Cox regression models.
 #' If \code{coxph} use \code{survival::coxph} else use \code{rms::cph}.
-#' @param iid logical. Compute the value of the influence function for each Cox model and store it in the (cause-specific) Cox regression object.
 #' @param ... Arguments given to \code{coxph}.
 #' @return \item{models }{a list with the fitted (cause-specific) Cox
 #' regression objects} \item{response }{the event history response }
@@ -47,7 +46,7 @@
 ##' ## fit two cause-specific Cox models
 ##' ## different formula for the two causes
 ##' fit1 <- CSC(list(Hist(time,status)~sex,Hist(time,status)~invasion+epicel+age),
-##'             data=Melanoma, iid = TRUE)
+##'             data=Melanoma)
 ##' print(fit1)
 ##'
 ##' 
@@ -128,7 +127,6 @@ CSC <- function(formula,
                 cause,
                 survtype="hazard",
                 fitter="coxph",
-                iid=TRUE,
                 ## strip.environment
                 ...){
     fitter <- match.arg(fitter,c("coxph","cph","phreg"))
@@ -221,10 +219,10 @@ CSC <- function(formula,
         
         workData <- data.frame(time=time,status=statusX)
         if(fitter=="phreg"){
-          if("entry" %in% names(data)){
-            stop("data must not contain a column named \"entry\" when using fitter=\"phreg\"")
-          }
-          workData$entry <- 0
+            if("entry" %in% names(data)){
+                stop("data may not contain a column named \"entry\" when using fitter=\"phreg\"")
+            }
+            workData$entry <- 0
         }
         ## to interprete formula
         ## we need the variables. in case of log(age) terms
@@ -256,20 +254,9 @@ CSC <- function(formula,
     }else{
         names(CoxModels) <- c(paste("Cause",theCause),"OverallSurvival")
     }
-    # }}}
-    # {{{ compute the value of the influence function for each observation
-    if(iid){
-        IF <- lapply(CoxModels,function(x){
-            iidCox(x)
-        })
-        names(IF) <- names(CoxModels)
-    }else{
-        IF <- NULL
-    }
-    # }}}
+    # }}}    
     out <- list(call=call,
                 models=CoxModels,
-                iid=IF,
                 response=response,
                 eventTimes=eventTimes,
                 survtype=survtype,
