@@ -17,13 +17,13 @@
 getComparisons <- function(dt,NF,N,alpha,dolist=NF:1){
     ## IMPORTANT: this function assumes that the
     ##            data are ordered according to model,times
-    x=model=IC=NULL
+    x=model=IF=NULL
     if (length(dolist)>0){
         Qnorm <- qnorm(1 - alpha/2)
         data.table::rbindlist(lapply(dolist,function(g){
             theta <- dt[,list(x=x[1]),by=model]
             delta <- theta[model%in%g[-1]][["x"]]-theta[model==g[1]][["x"]]
-            se.delta <- dt[model%in%g[-1],list(se=sd(dt[model==g[1]][["IC"]]-IC)/sqrt(N)),by=model][["se"]]
+            se.delta <- dt[model%in%g[-1],list(se=sd(dt[model==g[1]][["IF"]]-IF)/sqrt(N)),by=model][["se"]]
             lower <- delta - Qnorm * se.delta
             upper <- delta + Qnorm * se.delta
             p <-2*pnorm(abs(delta)/se.delta,lower.tail=FALSE)
